@@ -1,3 +1,3 @@
 # Place holder to designate directory as a package.
 #from .BenrulesRealTimeSim import BenrulesRealTimeSim
-from neural_body import BenrulesRealTimeSim
\ No newline at end of file
+from neural_body.BenrulesRealTimeSim_v3 import BenrulesRealTimeSim
\ No newline at end of file
